@@ -470,7 +470,7 @@ def test_preprocess_chooseOne(args, img_id):
         noise_im = noise_im[0:args.test_datasize, :, :]
     if args.print_img_name:
        print('Testing image name -----> ', im_name)
-       print('Noise images shape -----> ', noise_im.shape)
+       print('Testing image shape -----> ', noise_im.shape)
     # Minus mean before training
     noise_im = noise_im.astype(np.float32)/args.scale_factor
     noise_im = noise_im-img_mean
