@@ -3,8 +3,8 @@ Suite of functions that help display movie
 
 """
 import matplotlib
-matplotlib.use('TkAgg')
 import matplotlib.pyplot as plt
+
 import tifffile as tiff
 import cv2
 import numpy as np
@@ -33,7 +33,7 @@ def display(filename, display_length, norm_min_percent, norm_max_percent):
         cv2.waitKey(33)
     cv2.destroyWindow('Raw video')
 
-def display_img(filename, norm_min_percent, norm_max_percent, scale_num):
+def display_img(filename, norm_min_percent, norm_max_percent):
     img = tiff.imread(filename)
     img = img.astype(np.float32)
     t, x, y = img.shape[0:3]
@@ -42,11 +42,9 @@ def display_img(filename, norm_min_percent, norm_max_percent, scale_num):
     img = normalize(img, norm_min_percent, norm_max_percent)
     img = img * 255
 
-    img = cv2.resize(img, (int(y / scale_num), int(x / scale_num)))
+    return img
     # show_img = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
-    plt.imshow(img,cmap=plt.cm.gray,vmin=0,vmax=255)
-    plt.axis('off')
-    plt.show()
+
 
 
 
